@@ -101,7 +101,7 @@ import warnings
 import weakref
 from collections import OrderedDict, defaultdict
 from copy import deepcopy
-from inspect import Parameter, _empty, signature
+from inspect import Parameter, _empty, signature  # noqa
 from os import PathLike
 from pathlib import Path
 from types import ModuleType
@@ -134,7 +134,7 @@ from .locales import (
     read_locale_file,
 )
 from .options import METADATA_LOCALES, MISSING_METHODS, MISSING_OPTIONS, OPTIONS
-from .units import FREQ_NAMES, convert_units_to, declare_units, units
+from .units import FREQ_NAMES, convert_units_to, declare_units, units  # noqa
 from .utils import (
     VARIABLES,
     InputKind,
@@ -186,7 +186,8 @@ class IndicatorRegistrar:
             if inst is not None:
                 return inst
         raise ValueError(
-            f"There is no existing instance of {cls.__name__}. Either none were created or they were all garbage-collected."
+            f"There is no existing instance of {cls.__name__}. "
+            "Either none were created or they were all garbage-collected."
         )
 
 
@@ -199,9 +200,9 @@ class Indicator(IndicatorRegistrar):
 
     Instantiating a new indicator returns an instance but also creates and registers a custom subclass.
 
-    Parameters in `Indicator._cf_names` will be added to the output variable(s). When creating new `Indicators` subclasses,
-    if the compute function returns multiple variables, attributes may be given as lists of strings or strings.
-    In the latter case, the same value is used on all variables.
+    Parameters in `Indicator._cf_names` will be added to the output variable(s). When creating new `Indicators`
+    subclasses, if the compute function returns multiple variables, attributes may be given as lists of strings or
+    strings. In the latter case, the same value is used on all variables.
 
     Compared to their base `compute` function, indicators add the possibility of using dataset as input,
     with the injected argument `ds` in the call signature. All arguments that were indicated by the compute function
@@ -359,7 +360,10 @@ class Indicator(IndicatorRegistrar):
         kwds["parameters"] = params
 
         # By default skip missing values handling if there is no resampling.
-        if "freq" not in params:
+        # Dont only check if freq is in current parameters but also if it was injected earlier.
+        if "freq" not in params and "freq" not in getattr(
+            kwds["compute"], "_injected", {}
+        ):
             kwds["missing"] = "skip"
 
         # Parse kwds to organize cf_attrs
@@ -420,7 +424,8 @@ class Indicator(IndicatorRegistrar):
                 values = [values] * n_outs
             elif len(values) != n_outs:
                 raise ValueError(
-                    f"Attribute {name} has {len(values)} elements but should have {n_outs} according to passed var_name."
+                    f"Attribute {name} has {len(values)} elements but "
+                    f"should have {n_outs} according to passed var_name."
                 )
             for attrs, value in zip(cf_attrs, values):
                 if value:
@@ -473,8 +478,8 @@ class Indicator(IndicatorRegistrar):
         metadata_placeholders = {}
         if "index_function" in data:
             # Generate compute function
-            # data.index_function.name refers to a function in xclim.indices.generic or xclim.indices (in this order of priority).
-            # It can also directly be a function.
+            # data.index_function.name refers to a function in xclim.indices.generic
+            # or xclim.indices (in this order of priority). It can also directly be a function.
             # data.index_function.parameters is a list of injected arguments.
             funcname = data["index_function"].get("name")
             if funcname is None:
@@ -484,7 +489,7 @@ class Indicator(IndicatorRegistrar):
                 compute = funcname
             else:
                 compute = getattr(
-                    indices.generic, funcname, getattr(indices, funcname, None)
+                    indices.generic, funcname, getattr(indices, funcname, None)  # noqa
                 )
                 if compute is None:
                     raise ImportError(
@@ -654,7 +659,8 @@ class Indicator(IndicatorRegistrar):
             and parse_offset(all_params["freq"])[1] not in self.allowed_periods
         ):
             raise ValueError(
-                f"Resampling frequency {all_params['freq']} is not allowed for indicator {self.identifier} (needs something equivalent to one of {self.allowed_periods})."
+                f"Resampling frequency {all_params['freq']} is not allowed for indicator "
+                f"{self.identifier} (needs something equivalent to one of {self.allowed_periods})."
             )
 
         # Compute the indicator values, ignoring NaNs and missing values.
@@ -1283,6 +1289,7 @@ def build_indicator_module_from_yaml(
     keywords: Optional[str] = None,
     references: Optional[str] = None,
     notes: Optional[str] = None,
+    encoding: str = "UTF8",
 ) -> ModuleType:
     """Build or extend an indicator module from a YAML file.
 
@@ -1318,6 +1325,9 @@ def build_indicator_module_from_yaml(
       Other indicator attributes that would apply to all indicators in this module.
       Values given here are overridden by the ones given in individual definition, but
       they override the ones given at top-level in the YAMl file.
+    encoding: str
+      The encoding used to open the `.yaml` and `.json` files.
+      It defaults to UTF-8, overriding python's mechanism which is machine dependent.
 
     Returns
     -------
@@ -1350,7 +1360,7 @@ def build_indicator_module_from_yaml(
         ymlpath = filepath
 
     # Read YAML file
-    with ymlpath.open() as f:
+    with ymlpath.open(encoding=encoding) as f:
         yml = safe_load(f)
 
     # Load values from top-level in yml.
@@ -1371,7 +1381,9 @@ def build_indicator_module_from_yaml(
             translations = {}
             for locfile in filepath.parent.glob(filepath.stem + ".*.json"):
                 locale = locfile.suffixes[0][1:]
-                translations[locale] = read_locale_file(locfile, module=module_name)
+                translations[locale] = read_locale_file(
+                    locfile, module=module_name, encoding=encoding
+                )
 
     # Module-wide default values for some attributes
     defkwargs = {
