@@ -1,11 +1,12 @@
 """Atmospheric conversion definitions."""
-from inspect import _empty
+from inspect import _empty  # noqa
 
 from xclim import indices
 from xclim.core.indicator import Indicator
 from xclim.core.utils import wrapped_partial
 
 __all__ = [
+    "humidex",
     "tg",
     "wind_speed_from_vector",
     "wind_vector_from_speed",
@@ -15,6 +16,9 @@ __all__ = [
     "specific_humidity",
     "snowfall_approximation",
     "rain_approximation",
+    "wind_chill_index",
+    "potential_evapotranspiration",
+    "water_budget",
 ]
 
 
@@ -24,9 +28,19 @@ class Converter(Indicator):
     missing = "skip"
 
 
+humidex = Converter(
+    identifier="humidex",
+    units="C",
+    standard_name="air_temperature",
+    long_name="humidex index",
+    description="Humidex index describing the temperature felt by the average person in response to relative humidity.",
+    cell_methods="",
+    compute=indices.humidex,
+)
+
+
 tg = Converter(
     identifier="tg",
-    nvar=2,
     units="K",
     standard_name="air_temperature",
     long_name="Daily mean temperature",
@@ -38,7 +52,6 @@ tg = Converter(
 
 wind_speed_from_vector = Converter(
     identifier="wind_speed_from_vector",
-    nvar=2,
     var_name=["sfcWind", "sfcWindfromdir"],
     units=["m s-1", "degree"],
     standard_name=["wind_speed", "wind_from_direction"],
@@ -55,7 +68,6 @@ wind_speed_from_vector = Converter(
 
 wind_vector_from_speed = Converter(
     identifier="wind_vector_from_speed",
-    nvar=2,
     var_name=["uas", "vas"],
     units=["m s-1", "m s-1"],
     standard_name=["eastward_wind", "northward_wind"],
@@ -71,7 +83,6 @@ wind_vector_from_speed = Converter(
 
 saturation_vapor_pressure = Converter(
     identifier="e_sat",
-    nvar=1,
     units="Pa",
     long_name="Saturation vapor pressure",
     description=lambda **kws: (
@@ -88,9 +99,9 @@ saturation_vapor_pressure = Converter(
 
 
 relative_humidity_from_dewpoint = Converter(
-    identifier="rh_fromdewpoint",
-    nvar=2,
+    identifier="hurs_fromdewpoint",
     units="%",
+    var_name="hurs",
     long_name="Relative Humidity",
     standard_name="relative_humidity",
     title="Relative humidity from temperature and dewpoint temperature.",
@@ -106,7 +117,7 @@ relative_humidity_from_dewpoint = Converter(
     ),
     compute=wrapped_partial(
         indices.relative_humidity,
-        suggested={"dtas": _empty},
+        suggested={"tdps": _empty},
         huss=None,
         ps=None,
         invalid_values="mask",
@@ -115,8 +126,7 @@ relative_humidity_from_dewpoint = Converter(
 
 
 relative_humidity = Converter(
-    identifier="rh",
-    nvar=3,
+    identifier="hurs",
     units="%",
     long_name="Relative Humidity",
     standard_name="relative_humidity",
@@ -132,14 +142,13 @@ relative_humidity = Converter(
         else ""
     ),
     compute=wrapped_partial(
-        indices.relative_humidity, dtas=None, invalid_values="mask"
+        indices.relative_humidity, tdps=None, invalid_values="mask"
     ),
 )
 
 
 specific_humidity = Converter(
     identifier="huss",
-    nvar=3,
     units="",
     long_name="Specific Humidity",
     standard_name="specific_humidity",
@@ -159,7 +168,6 @@ specific_humidity = Converter(
 
 snowfall_approximation = Converter(
     identifier="prsn",
-    nvar=2,
     units="kg m-2 s-1",
     standard_name="solid_precipitation_flux",
     long_name="Solid precipitation",
@@ -170,9 +178,9 @@ snowfall_approximation = Converter(
     compute=indices.snowfall_approximation,
 )
 
+
 rain_approximation = Converter(
     identifier="prlp",
-    nvar=2,
     units="kg m-2 s-1",
     standard_name="precipitation_flux",
     long_name="Liquid precipitation",
@@ -182,3 +190,45 @@ rain_approximation = Converter(
     ),
     compute=indices.rain_approximation,
 )
+
+
+wind_chill_index = Converter(
+    identifier="wind_chill",
+    units="degC",
+    long_name="Wind chill index",
+    description=lambda **kws: (
+        "Wind chill index describing the temperature felt by the average person in response to cold wind."
+    )
+    + (
+        "A slow-wind version of the wind chill index was used for wind speeds under 5 km/h and invalid "
+        "temperatures were masked (T > 0°C)."
+        if kws["method"] == "CAN"
+        else "Invalid temperatures (T > 50°F) and winds (V < 3 mph) where masked."
+    ),
+    compute=wrapped_partial(indices.wind_chill_index, mask_invalid=True),
+)
+
+
+potential_evapotranspiration = Converter(
+    identifier="potential_evapotranspiration",
+    var_name="evspsblpot",
+    units="kg m-2 s-1",
+    standard_name="water_potential_evapotranspiration_flux",
+    long_name="Potential evapotranspiration",
+    description=(
+        "The potential for water evaporation from soil and transpiration by plants if the water "
+        "supply is sufficient, with the method {method}."
+    ),
+    compute=indices.potential_evapotranspiration,
+)
+
+water_budget = Converter(
+    identifier="water_budget",
+    units="kg m-2 s-1",
+    long_name="Water budget",
+    description=(
+        "Precipitation minus potential evapotranspiration as a measure of an approximated surface water budget, "
+        "where the potential evapotranspiration is calculated with the method {method}."
+    ),
+    compute=indices.water_budget,
+)
