@@ -10,6 +10,7 @@ from xarray.coding.cftimeindex import CFTimeIndex
 
 from xclim.core.calendar import (
     adjust_doy_calendar,
+    climatological_mean_doy,
     compare_offsets,
     convert_calendar,
     date_range,
@@ -382,6 +383,21 @@ def test_datetime_to_decimal_year(source_cal, exp180):
     np.testing.assert_almost_equal(decy[180] - 2004, exp180)
 
 
+def test_clim_mean_doy(tas_series):
+    arr = tas_series(np.ones(365 * 10))
+    mean, stddev = climatological_mean_doy(arr, window=1)
+
+    assert "dayofyear" in mean.coords
+    np.testing.assert_array_equal(mean.values, 1)
+    np.testing.assert_array_equal(stddev.values, 0)
+
+    arr = tas_series(np.arange(365 * 3), start="1/1/2001")
+    mean, stddev = climatological_mean_doy(arr, window=3)
+
+    np.testing.assert_array_equal(mean[1:-1], np.arange(365, 365 * 2)[1:-1])
+    np.testing.assert_array_almost_equal(stddev[1:-1], 298.0223, 4)
+
+
 def test_doy_to_days_since():
     # simple test
     time = date_range("2020-07-01", "2022-07-01", freq="AS-JUL")
