@@ -1,4 +1,3 @@
-import logging
 from collections import namedtuple
 
 import numpy as np
@@ -107,31 +106,6 @@ class TestDateHandling:
             tg_mean(da)
 
 
-def test_cf_compliance_options(tas_series, caplog):
-    tas = tas_series(np.ones(365))
-    tas.attrs["standard_name"] = "not the right name"
-
-    with caplog.at_level(logging.INFO):
-        with set_options(cf_compliance="log"):
-            cfchecks.check_valid_temperature(tas, "degK")
-
-            assert all([rec.levelname == "INFO" for rec in caplog.records])
-            assert (
-                "Variable has a non-conforming standard_name" in caplog.records[0].msg
-            )
-            assert "Variable has a non-conforming units" in caplog.records[1].msg
-
-    with pytest.warns(UserWarning, match="Variable has a non-conforming"):
-        with set_options(cf_compliance="warn"):
-            cfchecks.check_valid_temperature(tas, "degK")
-
-    with pytest.raises(
-        ValidationError, match="Variable has a non-conforming standard_name"
-    ):
-        with set_options(cf_compliance="raise"):
-            cfchecks.check_valid_temperature(tas, "degK")
-
-
 class TestDataCheck:
     def test_check_hourly(self, date_range):
         tas_attrs = {
@@ -150,25 +124,3 @@ class TestDataCheck:
             datachecks.check_freq(da, "H")
 
         datachecks.check_freq(da, "H", strict=False)
-
-
-def test_generated_cfchecks():
-    tas = xr.DataArray(
-        attrs=dict(
-            standard_name="air_temperature", cell_methods="time: mean within days"
-        )
-    )
-
-    cfchecks.generate_cfcheck("tas")(tas)
-
-    tas.attrs["standard_name"] = "air_feeling_of_heat"
-
-    with pytest.raises(ValidationError):
-        cfchecks.generate_cfcheck("tas")(tas)
-
-    sfcwind = xr.DataArray(
-        attrs=dict(standard_name="wind_speed", cell_methods="time: max within hours")
-    )
-
-    with pytest.raises(ValidationError):
-        cfchecks.generate_cfcheck("sfcWind")(sfcwind)
